@@ -27,9 +27,8 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#define _LARGEFILE_SOURCE
-#define _LARGEFILE64_SOURCE
 
+#include "config.h"
 #include "common.h"
 #include "util.h"
 #include <stdlib.h>
@@ -169,11 +168,7 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pa
   char num[80];
   uint64_t filesize;
   uint32_t parent_id = 0;
-#ifdef __USE_LARGEFILE64
-  struct stat64 sb;
-#else
   struct stat sb;
-#endif
   LIBMTP_track_t *trackmeta;
   LIBMTP_album_t *albuminfo;
   int ret;
@@ -191,20 +186,12 @@ int sendtrack_function(char * from_path, char * to_path, char *partist, char *pa
     return 1;
   }
 
-#ifdef __USE_LARGEFILE64
-  if ( stat64(from_path, &sb) == -1 ) {
-#else
   if ( stat(from_path, &sb) == -1 ) {
-#endif
     fprintf(stderr, "%s: ", from_path);
     perror("stat");
     return 1;
   } else if (S_ISREG (sb.st_mode)) {
-#ifdef __USE_LARGEFILE64
     filesize = sb.st_size;
-#else
-    filesize = (uint64_t) sb.st_size;
-#endif
     trackmeta->filetype = find_filetype (from_path);
     if (!LIBMTP_FILETYPE_IS_TRACK(trackmeta->filetype)) {
       printf("Not a valid track codec: \"%s\"\n", LIBMTP_Get_Filetype_Description(trackmeta->filetype));
